pub enum StoreError {
MissingRootDir,
InvalidMount(String),
TableMountIsLeaf(TablePath),
CorruptMount(String),
}Expand description
Store composition failures.
Variants
MissingRootDir
A composed expression tree must have a root Dir.
InvalidMount(String)
A mount path cannot be root and must not duplicate or conflict with existing mounts.
TableMountIsLeaf(TablePath)
A table mount was treated as a directory.
CorruptMount(String)
A persisted mount descriptor is corrupt.