CodecPolicyPatch

Struct CodecPolicyPatch 

pub struct CodecPolicyPatch {
    pub source_codec: Option<Option<String>>,
    pub source_position: Option<DecodePosition>,
    pub decode_limits: Option<DecodeLimits>,
    pub source_budget: Option<FaceBudget>,
    pub result_codec: Option<Option<String>>,
    pub result_position: Option<EncodePosition>,
    pub result_budget: Option<FaceBudget>,
}
Patch applied at the tree, directory, or cell policy level.

Codec selectors are stable exported names, not process-local CodecId values. The nested option permits a descendant to explicitly clear an inherited source or result codec.

Fields

source_codec: Option<Option<String>>

Inherit, clear, or replace the source codec name.

source_position: Option<DecodePosition>

Replace the source decode/encode position.

decode_limits: Option<DecodeLimits>

Replace the bounded source decode limits.

source_budget: Option<FaceBudget>

Replace the source-face resource budget.

result_codec: Option<Option<String>>

Inherit, clear, or replace the result codec name.

result_position: Option<EncodePosition>

Replace the result encode position.

result_budget: Option<FaceBudget>

Replace the result-face resource budget.

Implementations

Source

impl CodecPolicyPatch

pub fn empty() -> Self

No local policy changes.

pub fn set_codec(codec: impl Into<String>) -> Self

Selects the same codec for source and result faces.

pub fn clear_codec() -> Self

Clears inherited source and result codecs.

pub fn source_codec(codec: impl Into<String>) -> Self

Selects a source codec without changing any other field.

pub fn result_codec(codec: impl Into<String>) -> Self

Selects a result codec without changing any other field.