pub struct PendingCommit { /* private fields */ }Expand description
Recoverable source/control commit staged across separate backends.
Implementations
Sourceimpl PendingCommit
impl PendingCommit
Sourcepub fn source_committed(&self) -> bool
pub fn source_committed(&self) -> bool
Whether the source side of the transaction boundary was persisted.
Sourcepub fn control_committed(&self) -> bool
pub fn control_committed(&self) -> bool
Whether the control side of the transaction boundary was persisted.